==> mingw-w64-clang-aarch64-flecs-docs-4.0.1-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__cpp__addons__json.js <==
var group__cpp__addons__json =
[
    [ "flecs::entity::from_json", "group__cpp__addons__json.html#ga47edfb42247b4e13c3c1c07658be724e", null ],
    [ "flecs::world::from_json", "group__cpp__addons__json.html#ga356c77cce822897385366087ed9cae27", null ],
    [ "flecs::world::from_json", "group__cpp__addons__json.html#gae2f3a2131e31ef276a42e4d2acd9550a", null ],
    [ "flecs::world::from_json", "group__cpp__addons__json.html#gae93eb041a7e3aaef47727d87340f1615", null ],
    [ "flecs::world::from_json_file", "group__cpp__addons__json.html#ga23deed85c4e81e096cf8055f7f303cdd", null ],
    [ "flecs::entity_builder::set_json", "group__cpp__addons__json.html#gaf8f9794d1cca94722dbc8af8c2f97679", null ],
    [ "flecs::entity_builder::set_json", "group__cpp__addons__json.html#gae0dd6a23eb80e47ce2c17b24e9a01692", null ],
    [ "flecs::entity_builder::set_json", "group__cpp__addons__json.html#ga80c1e161a667c02603ce7bd226fa7019", null ],
    [ "flecs::entity_builder::set_json", "group__cpp__addons__json.html#gafbf781155476437fcf38d37e2380f8a8", null ],
    [ "flecs::entity_builder::set_json", "group__cpp__addons__json.html#gad6b8a4ab52df0cfbff91cf1a96896218", null ],
    [ "flecs::entity_builder::set_json_second", "group__cpp__addons__json.html#ga4c4de9b34edbf7fb3ef8dd1e56601a8c", null ],
    [ "flecs::entity_view::to_json", "group__cpp__addons__json.html#ga30ca7153aeaa3eb012f44d8aa3374e89", null ],
    [ "flecs::iter::to_json", "group__cpp__addons__json.html#ga6409d9ef8b8dd7b365ae41b3a96b416c", null ],
    [ "flecs::world::to_json", "group__cpp__addons__json.html#ga8c878935cdb8bb7740054bb6dd97ed0d", null ],
    [ "flecs::world::to_json", "group__cpp__addons__json.html#ga87909bb5dff358a28bb27a6f664010a7", null ],
    [ "flecs::world::to_json", "group__cpp__addons__json.html#gac150ac618ee74c75d3ae31f89dc06565", null ]
];

==> mingw-w64-clang-aarch64-flecs-docs-4.0.3-1-any.pkg.tar.zst: clangarm64/share/doc/flecs/html/group__cpp__addons__json.js <==
var group__cpp__addons__json =
[
    [ "flecs::entity::from_json", "group__cpp__addons__json.html#ga47edfb42247b4e13c3c1c07658be724e", null ],
    [ "flecs::world::from_json", "group__cpp__addons__json.html#ga356c77cce822897385366087ed9cae27", null ],
    [ "flecs::world::from_json", "group__cpp__addons__json.html#gae2f3a2131e31ef276a42e4d2acd9550a", null ],
    [ "flecs::world::from_json", "group__cpp__addons__json.html#gae93eb041a7e3aaef47727d87340f1615", null ],
    [ "flecs::world::from_json_file", "group__cpp__addons__json.html#ga23deed85c4e81e096cf8055f7f303cdd", null ],
    [ "flecs::entity_builder::set_json", "group__cpp__addons__json.html#gaf8f9794d1cca94722dbc8af8c2f97679", null ],
    [ "flecs::entity_builder::set_json", "group__cpp__addons__json.html#gae0dd6a23eb80e47ce2c17b24e9a01692", null ],
    [ "flecs::entity_builder::set_json", "group__cpp__addons__json.html#ga80c1e161a667c02603ce7bd226fa7019", null ],
    [ "flecs::entity_builder::set_json", "group__cpp__addons__json.html#gafbf781155476437fcf38d37e2380f8a8", null ],
    [ "flecs::entity_builder::set_json", "group__cpp__addons__json.html#gad6b8a4ab52df0cfbff91cf1a96896218", null ],
    [ "flecs::entity_builder::set_json_second", "group__cpp__addons__json.html#ga4c4de9b34edbf7fb3ef8dd1e56601a8c", null ],
    [ "flecs::entity_view::to_json", "group__cpp__addons__json.html#ga30ca7153aeaa3eb012f44d8aa3374e89", null ],
    [ "flecs::iter::to_json", "group__cpp__addons__json.html#ga6409d9ef8b8dd7b365ae41b3a96b416c", null ],
    [ "flecs::iter_iterable::to_json", "group__cpp__addons__json.html#ga6409d9ef8b8dd7b365ae41b3a96b416c", null ],
    [ "flecs::world::to_json", "group__cpp__addons__json.html#ga8c878935cdb8bb7740054bb6dd97ed0d", null ],
    [ "flecs::world::to_json", "group__cpp__addons__json.html#ga87909bb5dff358a28bb27a6f664010a7", null ],
    [ "flecs::world::to_json", "group__cpp__addons__json.html#gac150ac618ee74c75d3ae31f89dc06565", null ]
];
